package com.fuyuanshen.fyscustomer.controller;

import cn.hutool.core.collection.CollectionUtil;
import com.fuyuanshen.common.core.domain.ResponseVO;
import com.fuyuanshen.common.core.utils.StringUtils;
import com.fuyuanshen.fyscustomer.domain.Customer;
import com.fuyuanshen.fyscustomer.domain.query.UserQueryCriteria;
import com.fuyuanshen.fyscustomer.service.CustomerService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.undertow.util.BadRequestException;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Set;

/**
 * @author: 默苍璃
 * @date: 2025-07-0114:20
 */
@Slf4j
@Tag(name = "WEB：客户管理", description = "WEB：客户管理")
@RestController
@RequestMapping("/api/customers")
@RequiredArgsConstructor
public class CustomerController {

    private final CustomerService customerService;


    @GetMapping(value = "/allCustomer")
    @Operation(summary = "查询所有客户")
    public ResponseVO<List<Customer>> queryAllCustomer(UserQueryCriteria criteria) {
        List<Customer> customers = customerService.queryAllCustomers(criteria);
        return ResponseVO.success(customers);
    }


    // @Log("新增客户")
    @Operation(summary = "新增客户")
    @PostMapping(value = "/addCustomer")
    public ResponseVO<Object> addCustomer(@Validated @RequestBody Customer customer) throws BadRequestException {
        if (StringUtils.isBlank(customer.getPassword())) {
            throw new BadRequestException("账号密码不能为空");
        }
        customerService.addCustomer(customer);
        return ResponseVO.success("新增客户成功！！！");
    }


    // @Log("修改客户")
    @Operation(summary = "修改客户")
    @PutMapping(value = "updateCustomer")
    public ResponseVO<Object> updateCustomer(@RequestBody Customer resources) throws Exception {
        customerService.updateCustomer(resources);
        return ResponseVO.success(null);
    }


    // @Log("删除客户")
    @Operation(summary = "删除客户")
    @DeleteMapping(value = "/deleteCustomer")
    public ResponseVO<Object> deleteCustomer(@RequestBody Set<Long> ids) throws BadRequestException {
        if (CollectionUtil.isEmpty(ids)) {
            throw new BadRequestException("请选择要删除的客户");
        }
        customerService.delete(ids);
        return ResponseVO.success(null);
    }


}
